# LinkedIn Messaging API

An unofficial API for interacting with LinkedIn Messaging.

Built using [aiohttp](https://docs.aiohttp.org/en/stable/).

## Credits

Authentication technique from [@everping](https://github.com/everping) in the
[Linkedin-Authentication-Challenge](https://github.com/everping/Linkedin-Authentication-Challenge). Used with permission.
